@@ -13,6 +13,7 @@ use const INF;
 use function acos;
 use PHPUnit\Framework\Attributes\CoversClass;
 use PHPUnit\Framework\Attributes\DataProvider;
+use PHPUnit\Framework\Attributes\Small;
 use PHPUnit\Framework\Attributes\UsesClass;
 use PHPUnit\Framework\TestCase;
 
@@ -20,6 +21,7 @@ use PHPUnit\Framework\TestCase;
 #[UsesClass(Comparator::class)]
 #[UsesClass(ComparisonFailure::class)]
 #[UsesClass(Factory::class)]
+#[Small]
 final class NumericComparatorTest extends TestCase
 {
     /**
